local json = require("json")
local const = require("const")
local utils = require("utils")
local utils_device = require("utils_device")

local request_method = ngx.var.request_method

utils.check_login()
utils.check_permission("DeviceManage")

function get( ... )
    -- body
end

if ("GET" == request_method) then
    local args = ngx.req.get_uri_args()
    if (nil == args) then
        utils.error_exit(400, "invalid parameter")
    end

    driver = args["DriverName"]
    pk = args["ProductKey"]
    localid = args["DeviceLocalId"]

    utils.check_pk(pk)

    if (not (driver and localid)) then
        utils.error_exit(400, "invalid parameter")
    end

    local num, dev_info = utils_device.get_unauth_device_info(pk, localid)
    if (num) then
        dev_info["DeviceDetailInfo"] = 'None'
        utils.error_exit(200, json.encode(dev_info))
    else 
        utils.error_exit(200, '{}')
    end

elseif ("POST" == request_method) then
    ngx.req.read_body()
    local args_json = ngx.req.get_body_data()
    args = json.decode(args_json)
    if (nil == args) then
        utils.error_exit(400)
    end

    action = args["Action"]
    dev_num = tonumber(args["DeviceNum"])
    dev_list = args["List"]

    if (not ("PassCheck" == action and dev_num and dev_num > 0 and dev_list)) then
        utils.error_exit(400, "invalid parameter")
    end

    local res = {}
    res["List"] = {}
    local params = {}
    params["params"] = {}

    local success_num = #dev_list
    local fail_num = 0

    for _, dev in ipairs(dev_list) do 
        if (dev["ProductKey"] and dev["DeviceLocalId"]) then
            local item = {}
            table.insert(item, dev["ProductKey"])
            table.insert(item, dev["DeviceLocalId"])
            table.insert(params["params"], item)

            -- all is successfully by default 
            local res_item = {}
            res_item["DriverName"] = dev["DriverName"]
            res_item["ProductKey"] = dev["ProductKey"]
            res_item["DeviceLocalId"] = dev["DeviceLocalId"]
            res_item["State"] = "Success"
            res_item["ErrorDetail"] = ""
            table.insert(res["List"], res_item)

        else
            utils.error_exit(400, "invalid ProductKey or DeviceLocalId")
        end
    end

    local ok, msg_raw, err = utils.dbus_call_edge(const.dimu.wkn,
                                    const.dimu.obj,
                                    const.dimu.inf,
                                    "authorizeDevice",
                                    json.encode(params))
    if (ok and msg_raw) then
        local ok, msg = pcall(json.decode, msg_raw[1])
        if (ok and 0 ~= msg["code"]) then
            -- {"code":1,"message":"Failed to operate on some devices","params":{"failed":[0]}}
            local fail_list = msg["params"]["failed"]
            if (fail_list) then
                fail_num = #fail_list
                success_num = success_num - fail_num

                -- handle failed
                for _, i_fail in ipairs(fail_list) do    
                    res["List"][i_fail + 1]["State"] = "Fail"
                    res["List"][i_fail + 1]["ErrorDetail"] = "Dimu failed: " .. msg["message"]
                end
            else
                fail_num = 0
            end
        end
    else
        utils.log_error("get nothing from getDeviceTags:" .. err)
    end

    res["SuccessNum"] = success_num
    res["FailNum"] = fail_num
    utils.error_exit(200, json.encode(res))
end

utils.error_exit(400, "unsupported request method")
