local json = require("json")
local utils = require("utils")
local const = require("const")
local pl_dir = require("pl.dir")
local pl_path = require("pl.path")
local pl_file = require("pl.file")
local resty_string = require("resty.string")


function is_leaf_dir(path)
    local ok, dir_list = pcall(pl_dir.getdirectories, path)
    if (ok) then
        if (nil == dir_list or nil == next(dir_list)) then
            return true
        else
            return false
        end
    end

    utils.error_exit(400, "Permission denied on path:" .. path)
end

local function spairs(t, order)
    -- collect the keys
    local keys = {}
    for k in pairs(t) do keys[#keys+1] = k end

    -- if order function given, sort by it by passing the table and keys a, b,
    -- otherwise just sort the keys 
    if order then
        table.sort(keys, function(a,b) return order(t, a, b) end)
    else
        table.sort(keys)
    end

    -- return the iterator function
    local i = 0
    return function()
        i = i + 1
        if keys[i] then
            return keys[i], t[keys[i]]
        end
    end
end

local request_method = ngx.var.request_method

if (not utils.check_permission("LogManage")) then
    utils.error_exit(403)
end

if ("GET" == request_method) then
    local args = ngx.req.get_uri_args()
    if (nil == args) then
        utils.error_exit(400, "invalid parameter")
    end

    sub_path = args["Path"]
    if (nil == sub_path) then
        utils.error_exit(400, "invalid parameter")
    end

    -- get root path
    local ok, msg_dir = utils.get_data(const.data_key.logger.dir)
    if (ok) then
        if (not msg_dir) then
            utils.error_exit(200, '{"List":[ ]}')
        end
    else
        utils.log_error('get log root path failed')
        utils.error_exit(500, 'get log root path failed')
    end

    local root_path = msg_dir
    local res = {}
    res["List"] = {}
    local path = root_path .. '/' .. sub_path
    path = pl_path.normpath(path)

    if (not pl_path.exists(path)) then
        utils.error_exit(400, "unknow path")
    end

    local ok, file_list = pcall(pl_dir.getfiles, path)
    if (not ok) then
        utils.error_exit(400, "Permission denied on path: " .. path)
    end
    local tmp_list = {}
    for _, v in ipairs(file_list) do 
        local item = {}
        filename = pl_path.relpath(v, path)
        item["Name"] = filename
        item["Size"] = tostring(pl_path.getsize(v))
        item["Time"] = tostring(pl_file.modified_time(v))
        item["Type"] = "File"
        table.insert(tmp_list, item)
    end 

    local index = -1
    for k,v in spairs(tmp_list, function(t,a,b)
                                    return tonumber(t[a]["Time"]) > tonumber(t[b]["Time"])
                                end) 
    do
        if v["Name"] ~= "log.INFO" then
            table.insert(res["List"], v)
    
        end
    end
    local ok, dir_list = pcall(pl_dir.getdirectories, path)
    if (not ok) then
        utils.error_exit(400, "Permission denied on path: " .. path)
    end

    local tmp_list_dir = {}
    for _, v in ipairs(dir_list) do 
        local item = {}
        dirname = pl_path.relpath(v, path)
        item["Name"] = dirname
        item["Size"] = tostring(pl_path.getsize(v))
        item["Time"] = tostring(pl_path.getmtime(v))
        item["Type"] = "Dir"
        item["LeafDir"] = is_leaf_dir(v)
        table.insert(tmp_list_dir, item)
    end 
    
    for k,v in spairs(tmp_list_dir, function(t,a,b)
                                    return t[a]["Name"] < t[b]["Name"]
                                end) 
    do
        table.insert(res["List"], v)
    end
     
    utils.error_exit(200, json.encode(res))
end

utils.error_exit(400, "unsupported request method")
------ EOF ------
