local json = require("json")
local utils = require("utils")
local const = require("const")
local ck = require("resty.cookie")

local request_method = ngx.var.request_method

if "POST" ~= request_method then
    utils.error_exit(400, "unsupported request method")
end
local utils_header = require("utils_header")
local params = utils_header.check_public_boby_data()
local user = params["UserName"]

utils.check_username(user)
local cookie, err = ck:new()
if not cookie then
    utils.error_exit(401, err)
end

-- get login cookie
local login_token, err = cookie:get("loginToken")
if login_token then
    -- delete login cookie if existing
    local memkv = ngx.shared.memkv
    val = memkv:get(login_token)
    local user_mem = memkv:get(login_token .. "." .. "username")
    if (nil ~= val) and (user_mem == user) then
        memkv:delete(login_token)
        memkv:delete(login_token .. "." .. "username")
        utils.error_exit(200)
    end
end

utils.error_exit(401, "user is not logined.")

------ EOF ------
