local json = require("json")
local const = require("const")
local utils = require("utils")
local utils_device = require("utils_device")

local request_method = ngx.var.request_method

utils.check_login()
utils.check_permission("DeviceManage")

if ("POST" == request_method) then
    local utils_header = require("utils_header")
    local params = utils_header.check_public_boby_data()
    local dev_list = params["DeviceList"]
    
    if dev_list == nil or type(dev_list) ~= "table" or #dev_list <= 0 then
        utils.error_exit(400, "DeviceList should be json array.")
    end

    local cmd_params = {}
    
    for _, dev in ipairs(dev_list) do
        pk = dev["ProductKey"]
        dn = dev["DeviceName"]
        driver_name = dev["DriverName"]

        utils.check_pk(pk)
        utils.check_dn(dn)
   
        if driver_name == nil or type(driver_name) ~= "string" then
            utils.error_exit(400, "driver name must be string type")
        end
        local cmd = string.format(const.dimu.method.fmt_registerDevice, pk, dn, driver_name)

        local ok, msg_raw, err = utils.dbus_call_edge(const.dimu.wkn,
                                    const.dimu.obj,
                                    const.dimu.inf,
                                    const.dimu.method.registerDevice,
                                    cmd)

        if (ok and msg_raw) then
            local ok, msg = pcall(json.decode, msg_raw[1])
            if (not (ok and 0 == msg["code"])) then
                utils.error_exit(500, json.encode("falied to auth"))
            end
        else
            utils.error_exit(500, json.encode("falied to auth"))
        end
    end

    utils.error_exit(200)
end

utils.error_exit(400, "unsupported request method")
