#!/bin/bash

FC_MOUNT_SWITCH="off"
fc_no_isolation=$FC_NO_ISOLATION
if [ -n "$fc_no_isolation" ]; then
	echo "FC_NO_ISOLATION is $fc_no_isolation "
    FC_MOUNT_SWITCH="off"
fi

DPS_SWITCH="OFF"

#get gw_dps_switch value from config-manager
get_dps_switch() {
dps_commond=$(/linkedge/gateway/build/bin/tool_config -g gw_dps_switch 2>&1)
dps_switch_res=$(echo $dps_commond | grep -Eo "value:[0-9]+" | grep -Eo "[0-9]+")
if [[ $dps_switch_res == "1" ]]
then
  echo "dps is ON"
  DPS_SWITCH="ON"
else
  echo "dps is OFF"
  DPS_SWITCH="OFF"
fi
}
get_dps_switch

# Preparation for chroot START.Mount public dir.
HOME_DIR=`env | grep ^HOME= | cut -c 7-`
MOUNT_POINT=$(dirname $(readlink -f "$0"))
mount_array=($HOME_DIR tmp var sbin sys lib lib64 tmp/var/run bin dev usr etc run etc/resolv.conf proc linkedge/run linkedge/gateway/build/lib linkedge/gateway/build/bin/dps linkedge/pre-installed)

umount_fc() {
umount $MOUNT_POINT/$GW_LIB_DIR
for dir in ${mount_array[@]}
do
    umount -l $MOUNT_POINT/$dir
done
}

mount_fc() {
for dir in ${mount_array[@]}
do
    if [[ $dir != etc/resolv.conf ]]
    then
        mkdir -p $MOUNT_POINT/$dir
    fi

    mount --rbind /$dir $MOUNT_POINT/$dir
    mount --make-rslave $MOUNT_POINT/$dir
    if [[ $dir != tmp && $dir != tmp/var/run && $dir != linkedge/run && $dir != dev && $dir != proc && $dir != sys ]]
    then
    mount -o remount,ro,bind --make-rslave /$dir $MOUNT_POINT/$dir
    fi
done

# The 3 lines below is for system compatibility
#mkdir -p $MOUNT_POINT/var/run && touch $MOUNT_POINT/var/run/docker.sock
#mount --bind /var/run/docker.sock $MOUNT_POINT/var/run/docker.sock
mkdir -p $MOUNT_POINT/$GW_LIB_DIR
#mount --bind $MOUNT_POINT/../../lib $MOUNT_POINT/$GW_LIB_DIR
#mount -o remount,ro,bind $MOUNT_POINT/../../lib $MOUNT_POINT/$GW_LIB_DIR
}

#create configure file
#cp ../fc-base ./ -f
#cp ../start-ea.sh ./ -f
#cp ../stop-ea.sh ./ -f

if [ "$FC_MOUNT_SWITCH" == "on" ]; then
    GRAVITY_PATH=""
    GW_LIB_DIR=gw_lib
    umount_fc
    mount_fc
else
    GRAVITY_PATH=$(dirname $(readlink -f "$0"))
    GW_LIB_DIR=../../lib
fi

START_PARAM=$1
echo "start parameters:" $START_PARAM

ENV_PATH=$GRAVITY_PATH/build-env/node/bin
PYTHON_PATH=$GRAVITY_PATH/linkedge/gateway/build/bin/py3_venv/bin
export PATH=$PYTHON_PATH:$ENV_PATH:$PATH
#Export C dependency library lookup PATH
#export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$GRAVITY_PATH/$GW_LIB_DIR
#Export JS dependency library lookup PATH
export NODE_PATH=$GRAVITY_PATH/runtime/nodejs8/node_modules:$GRAVITY_PATH/$GW_LIB_DIR:$NODE_PATH

#Set maximum thread number of libuv: not exceeding 128
export UV_THREADPOOL_SIZE=96
export PYTHONPATH=$GRAVITY_PATH/$GW_LIB_DIR:$PYTHONPATH
export PYTHONUNBUFFERED=TRUE

#Start function-compute
APP="./fc-base"

if [ "$FC_MOUNT_SWITCH" == "on" ]; then
    if [ "$DPS_SWITCH" == "OFF" ]; then
        #Chroot to run the function-compute
        chroot $MOUNT_POINT $APP &
    else
        /linkedge/gateway/build/bin/dps/bin/sandbox -C $MOUNT_POINT $APP &
    fi
else
    $APP &
fi


